@@ -24,6 +24,8 @@ class Channel(object):
     def __init__(self):
         self.called = []
         self.deliveries = count(1).next
+        self.to_deliver = []
+        self.events = {"basic_return": []}
 
     def _called(self, name):
         self.called.append(name)
@@ -58,11 +60,18 @@ class Channel(object):
     def queue_bind(self, *args, **kwargs):
         self._called("queue_bind")
 
+    def queue_unbind(self, *args, **kwargs):
+        self._called("queue_unbind")
+
     def queue_delete(self, queue, if_unused=False, if_empty=False, **kwargs):
         self._called("queue_delete")
 
     def basic_get(self, *args, **kwargs):
         self._called("basic_get")
+        try:
+            return self.to_deliver.pop()
+        except IndexError:
+            pass
 
     def queue_purge(self, *args, **kwargs):
         self._called("queue_purge")
@@ -79,6 +88,9 @@ class Channel(object):
     def basic_recover(self, requeue=False):
         self._called("basic_recover")
 
+    def close(self):
+        self._called("close")
+
     def message_to_python(self, message, *args, **kwargs):
         self._called("message_to_python")
         return Message(self, body=simplejson.dumps(message),
